@@ -4,8 +4,9 @@ OC.L10N.register(
     "Details" : "Detil",
     "All contacts" : "Semua kontak",
     "Contacts" : "Kontak",
-    "Download" : "Unduh",
+    "A contacts app for Nextcloud" : "Sebuah aplikasi kontak untuk Nextcloud",
     "Send email" : "Kirim surel",
+    "Download" : "Unduh",
     "Rename" : "Ubah nama",
     "Enabled" : "Diaktifkan",
     "Delete" : "Hapus",
@@ -20,28 +21,29 @@ OC.L10N.register(
     "Password protection" : "Password protection",
     "Save" : "Simpan",
     "Description" : "Deskrisi",
+    "Cancel" : "Membatalkan",
     "Invalid image" : "Gambar tidak sah",
     "Name" : "Nama",
     "Title" : "Judul",
-    "Cancel" : "Membatalkan",
     "New contact" : "Kontak baru",
     "Search contacts …" : "Cari kontak ...",
     "No results" : "Tidak ada hasil",
     "Pending" : "Tunggu",
+    "None" : "Tidak ada",
     "Close" : "Tutup",
     "Import" : "Impor",
     "Not grouped" : "Tidak dikelompokkan",
     "User" : "Pengguna",
     "Group" : "Grup",
-    "Email" : "Email",
+    "Email" : "Surel",
     "Admin" : "Admin",
     "Owner" : "Owner",
     "Users" : "Pengguna",
-    "Nickname" : "Nama panggilan",
     "Detailed name" : "Nama lengkap",
     "Additional names" : "Nama tambahan",
     "Prefix" : "Prefix",
     "Suffix" : "Suffix",
+    "Nickname" : "Nama panggilan",
     "Notes" : "Catatan",
     "Website" : "Situs Web",
     "Location" : "Lokasi",
@@ -67,7 +69,6 @@ OC.L10N.register(
     "Pager" : "Pager",
     "Voice" : "Suara",
     "Social network" : "Media sosial",
-    "None" : "Tidak ada",
     "Unknown" : "Tidak diketahui"
 },
 "nplurals=1; plural=0;");
