@@ -29,7 +29,6 @@ OC.L10N.register(
     "Update avatars from social media" : "SNSでアバターをアップデート",
     "(refreshed once per week)" : "(週に1回更新)",
     "Address books" : "アドレス帳",
-    "Download" : "ダウンロード",
     "Send email" : "メールを送信",
     "Contact groups" : "連絡先グループ",
     "Create a new contact group" : "新規連絡先グループを作成",
@@ -43,6 +42,7 @@ OC.L10N.register(
     "This group already exists" : "このグループはすでに存在しています",
     "This circle already exists" : "このサークルはすでに存在します",
     "An error happened during the creation of the circle" : "サークルの作成中にエラーが発生しました",
+    "Download" : "ダウンロード",
     "Rename" : "名前を変更",
     "Enabled" : "有効",
     "Delete" : "削除",
@@ -93,15 +93,13 @@ OC.L10N.register(
     "Enter a description for the circle" : "サークルについて説明を入力してください",
     "An error happened during description sync" : "説明の同期中にエラーが発生しました",
     "An error happened during name sync" : "名前の同期中にエラーが発生しました",
-    "Add new property" : "新しいプロパティを追加する",
-    "Choose property type" : "プロパティの種類を選択",
+    "Cancel" : "キャンセル",
     "Upload a new picture" : "新しい写真をアップロードする",
     "Choose from Files" : "ファイルから選択",
     "Get from " : "次から入手:",
     "Download picture" : "画像をダウンロード",
     "Delete picture" : "画像を削除",
     "Invalid image" : "無効な画像",
-    "Image is too big (max 1MB)." : "画像容量が大きすぎます (最大1 MB)",
     "Pick an avatar" : "アバターを選択",
     "Error while processing the picture." : "画像の加工中にエラーが発生しました",
     "Avatar downloaded from social network" : "SNSでダウンロード済みのアバター",
@@ -110,16 +108,14 @@ OC.L10N.register(
     "No contact selected" : "連絡先が選択されていません",
     "Select a contact on the list to begin" : "開始するには、リストの連絡先を選択してください",
     "Name" : "名前",
-    "Company" : "会社",
     "Title" : "タイトル",
+    "Company" : "会社",
     "This contact was broken and received a fix. Please review the content and click here to save it." : "この連絡先は変更され、修正を受信しました。内容を確認してクリックで保存してください。",
     "Clone contact" : "連絡先の複製",
     "Generate QR Code" : "QRコードを生成",
     "Contact vCard as QR code" : "QRコードでの連絡先vCard",
     "Pick an address book" : "アドレス帳を選ぶ",
     "Select address book" : "アドレス帳を選ぶ",
-    "Cancel" : "キャンセル",
-    "This contact is not yet synced. Edit it to save it to the server." : "この連絡先はまだ同期されていません。 それを編集してサーバーに保存してください。",
     "This contact is in read-only mode. You do not have permission to edit this contact." : "この連絡先は読み取り専用モードです。 この連絡先を編集する権限がありません。",
     "The contact you were trying to edit has changed. Please manually refresh the contact. Any further edits will be discarded." : "編集しようとした連絡先が変更されました。 連絡先を手動で更新してください。 それ以上の編集は破棄されます。",
     "Address book" : "アドレス帳",
@@ -127,7 +123,6 @@ OC.L10N.register(
     "Exclude contact from Birthday Calendar" : "誕生日カレンダーから連絡先を除外する",
     "New contact" : "新しい連絡先",
     "Syntax error. Cannot open the contact." : "構文エラー。 連絡先を開けません",
-    "The contact does not exists on the server anymore." : "その連絡先はサーバーにはもう存在しません",
     "Unable to retrieve the contact from the server, please check your network connection." : "サーバーから連絡先を取得できないので、ネットワークの接続をご確認ください。",
     "An error occurred while trying to move the contact" : "連絡先の移動中にエラーが発生しました",
     "An error occurred while trying to copy the contact" : "連絡先のコピー中にエラーが発生しました",
@@ -147,6 +142,7 @@ OC.L10N.register(
     "Create circle" : "サークルを作成",
     "Loading members list …" : "メンバーリストを読み込んでいます…",
     "The list of members is only visible to members of this circle" : "メンバーのリストは、このサークルのメンバーにのみ表示されます",
+    "You currently have no access to the member list" : "メンバーリストへのアクセス権がありません",
     "Add members" : "メンバーの追加",
     "Show circle details" : "サークル詳細を表示",
     "Add to {circle}" : "{circle} に追加",
@@ -169,6 +165,7 @@ OC.L10N.register(
     "Select chart …" : "組織図を選択...",
     "Select type" : "タイプを選択",
     "Select Date" : "日付を選択",
+    "None" : "なし",
     "Add contact in group" : "グループに連絡先を追加",
     "Select option" : "オプションを選択",
     "Unable to create the contact." : "連絡先を追加できません。",
@@ -215,11 +212,12 @@ OC.L10N.register(
     "Circle membership" : "サークルメンバーシップ",
     "Prevent circle from being a member of another circle" : "サークルが別のサークルのメンバーにならないようにする",
     "Users" : "ユーザー",
-    "Nickname" : "ニックネーム",
+    "Email addresses" : "メールアドレス",
     "Detailed name" : "詳細名",
     "Additional names" : "ミドルネーム",
     "Prefix" : "プレフィックス",
     "Suffix" : "サフィックス",
+    "Nickname" : "ニックネーム",
     "Notes" : "ノート",
     "Website" : "ウェブサイト",
     "Location" : "場所",
@@ -270,12 +268,10 @@ OC.L10N.register(
     "Gender" : "性別",
     "Female" : "女性",
     "Male" : "男性",
-    "None" : "なし",
     "Unknown" : "不明",
     "Time zone" : "時間帯",
     "Spoken languages" : "話せる言語",
     "_{failed} contact failed to be read_::_{failed} contacts failed to be read_" : ["{failed}連絡先の読み込みができませんでした。"],
-    "Some circle(s) an error occurred. Check the console for more details." : "一部のサークルでエラーが発生しました。詳細については、コンソールを確認してください。",
     "Unable to create circle {circleName}" : "サークル {circleName} を作成できません",
     "Unable to delete circle {circleId}" : "サークル{circleId}を削除できません",
     "Unable to delete contact" : "連絡先を削除できません。"
