@@ -23,11 +23,13 @@ OC.L10N.register(
     "Add member" : "회원 추가",
     "Leave circle" : "서클 떠나기",
     "Delete circle" : "서클 삭제",
+    "Contacts settings" : "연락처 설정",
     "General settings" : "일반 설정",
     "Update avatars from social media" : "소셜 네트워크에서 아바타 업데이트",
     "(refreshed once per week)" : "(주 1회 새로고침)",
-    "Download" : "다운로드",
+    "Address books" : "주소록",
     "Send email" : "이메일 보내기",
+    "Contact groups" : "연락처 그룹",
     "Circles" : "서클",
     "Create a new circle" : "새 서클 만들기",
     "Show all groups" : "모든 그룹 보이기",
@@ -36,6 +38,7 @@ OC.L10N.register(
     "Collapse circles" : "서클 접기",
     "This group already exists" : "그룹이 이미 존재함",
     "This circle already exists" : "서클이 이미 존재함",
+    "Download" : "다운로드",
     "Rename" : "이름 바꾸기",
     "Enabled" : "활성화됨",
     "Delete" : "삭제",
@@ -75,15 +78,13 @@ OC.L10N.register(
     "There is no description for this circle" : "이 서클에는 설명이 없음",
     "Enter a description for the circle" : "이 서클에 대한 설명 입력",
     "An error happened during description sync" : "설명 동기화 중 오류 발생",
-    "Add new property" : "새 속성 추가",
-    "Choose property type" : "속성 종류 선택",
+    "Cancel" : "취소",
     "Upload a new picture" : "새 그림 업로드",
     "Choose from Files" : "파일에서 선택",
     "Get from " : "가져오기 - ",
     "Download picture" : "그림 다운로드",
     "Delete picture" : "그림 삭제",
     "Invalid image" : "잘못된 사진",
-    "Image is too big (max 1MB)." : "그림이 너무 큽니다(최대 1MB).",
     "Pick an avatar" : "아바타 선택",
     "Error while processing the picture." : "그림을 처리하는 중 오류가 발생했습니다.",
     "Avatar downloaded from social network" : "소셜 네트워크에서 아바타가 다운로드 되었습니다",
@@ -92,16 +93,14 @@ OC.L10N.register(
     "No contact selected" : "선택한 연락처 없음",
     "Select a contact on the list to begin" : "목록에서 연락처를 선택하여 시작하십시오",
     "Name" : "이름",
-    "Company" : "회사",
     "Title" : "직위",
+    "Company" : "회사",
     "This contact was broken and received a fix. Please review the content and click here to save it." : "연락처가 잘못되었으며 수정이 필요합니다. 내용을 점검하고 여기를 눌러 저장하십시오.",
     "Clone contact" : "연락처 복제",
     "Generate QR Code" : "QR 코드 생성",
     "Contact vCard as QR code" : "QR 코드로 된 vCard 연락처",
     "Pick an address book" : "주소록을 선택하세요",
     "Select address book" : "주소록 선택",
-    "Cancel" : "취소",
-    "This contact is not yet synced. Edit it to save it to the server." : "이 연락처를 동기화하지 않았습니다. 편집하면 서버에 저장합니다.",
     "This contact is in read-only mode. You do not have permission to edit this contact." : "이 연락처는 읽기 전용 모드입니다. 편집할 수 있는 권한이 없습니다.",
     "The contact you were trying to edit has changed. Please manually refresh the contact. Any further edits will be discarded." : "편집하려고 하는 연락처가 변경되었습니다. 연락처를 직접 새로 고치십시오. 추가 변경 사항은 손실됩니다.",
     "Address book" : "주소록",
@@ -141,6 +140,7 @@ OC.L10N.register(
     "Could not change the member level to {level}" : "회원 레벨을 {level}로 바꿀 수 없습니다",
     "Select type" : "종류 선택",
     "Select Date" : "날짜 선택",
+    "None" : "없음",
     "Add contact in group" : "그룹에 연락처 추가",
     "Select option" : "옵션 선택",
     "Unable to create the contact." : "연락처를 만들 수 없습니다.",
@@ -186,11 +186,11 @@ OC.L10N.register(
     "Circle membership" : "서클 회원",
     "Prevent circle from being a member of another circle" : "이 서클이 다른 서클의 회원이 될 수 없음",
     "Users" : "사용자",
-    "Nickname" : "별명",
     "Detailed name" : "자세한 이름",
     "Additional names" : "추가 이름",
     "Prefix" : "접두사",
     "Suffix" : "접미사",
+    "Nickname" : "별명",
     "Notes" : "메모",
     "Website" : "웹 사이트",
     "Location" : "위치",
@@ -241,11 +241,9 @@ OC.L10N.register(
     "Gender" : "성별",
     "Female" : "여성",
     "Male" : "남성",
-    "None" : "없음",
     "Unknown" : "알 수 없음",
     "Spoken languages" : "사용 언어",
     "_{failed} contact failed to be read_::_{failed} contacts failed to be read_" : ["연락처 {failed}개를 읽을 수 없음"],
-    "Some circle(s) an error occurred. Check the console for more details." : "일부 서클에서 오류가 발생함. 자세한 사항은 콘솔 참조하십시오.",
     "Unable to create circle {circleName}" : "{circleName} 서클을 만들 수 없음",
     "Unable to delete circle {circleId}" : "{circleId} 서클을 삭제할 수 없음",
     "Unable to delete contact" : "연락처를 삭제할 수 없음"
