@@ -21,13 +21,13 @@ OC.L10N.register(
     "Update avatars from social media" : "อัปเดตภาพแทนตัวจากโซเชียลมีเดีย",
     "(refreshed once per week)" : "(รีเฟรชใหม่สัปดาห์ละครั้ง)",
     "Address books" : "สมุดรายชื่อ",
-    "Download" : "ดาวน์โหลด",
     "Send email" : "ส่งอีเมล",
     "Contact groups" : "กลุ่มรายชื่อ",
     "Create a new contact group" : "สร้างกลุ่มรายชื่อใหม่",
     "Contact group name" : "ชื่อของกลุ่มรายชื่อ",
     "Show all groups" : "แสดงกลุ่มทั้งหมด",
     "Collapse groups" : "ย่อกลุ่ม",
+    "Download" : "ดาวน์โหลด",
     "Rename" : "เปลี่ยนชื่อ",
     "Enabled" : "เปิดใช้งานอยู่",
     "Delete" : "ลบ",
@@ -46,23 +46,24 @@ OC.L10N.register(
     "Save" : "บันทึก",
     "Request to join" : "ขอเข้าร่วม",
     "Description" : "รายละเอียด",
+    "Cancel" : "ยกเลิก",
     "Upload a new picture" : "อัปโหลดรูปภาพใหม่",
     "Choose from Files" : "เลือกจากไฟล์",
     "Get from " : "รับจาก",
     "Download picture" : "ดาวน์โหลดรูปภาพ",
     "Delete picture" : "ลบรูปภาพ",
     "Invalid image" : "รูปภาพไม่ถูกต้อง",
-    "Image is too big (max 1MB)." : "รูปภาพใหญ่เกินไป (สูงสุด 1MB)",
     "Pick an avatar" : "เลือกภาพแทนตัว",
     "Error while processing the picture." : "เกิดข้อผิดพลาดขณะประมวลผลรูปภาพ",
     "Name" : "ชื่อ",
-    "Company" : "บริษัท",
     "Title" : "ชื่อเรื่อง",
-    "Cancel" : "ยกเลิก",
+    "Company" : "บริษัท",
+    "Edit" : "แก้ไข",
     "New contact" : "รายชื่อใหม่",
     "Search contacts …" : "ค้นหารายชื่อผู้ติดต่อ …",
     "No results" : "ไม่มีผลลัพธ์",
     "Pending" : "รอดำเนินการ",
+    "None" : "ไม่มี",
     "Select option" : "เลือกตัวเลือก",
     "Close" : "ปิด",
     "Import" : "นำเข้า",
@@ -73,11 +74,11 @@ OC.L10N.register(
     "Admin" : "ผู้ดูแลระบบ",
     "Owner" : "เจ้าของ",
     "Users" : "ผู้ใช้",
-    "Nickname" : "ชื่อเล่น",
     "Detailed name" : "ชื่อโดยละเอียด",
     "Additional names" : "ชื่ออื่น ๆ",
     "Prefix" : "คำนำหน้า",
     "Suffix" : "คำต่อท้าย",
+    "Nickname" : "ชื่อเล่น",
     "Notes" : "โน้ต",
     "Website" : "เว็บไซต์",
     "Location" : "ตำแหน่งที่อยู่",
@@ -104,7 +105,6 @@ OC.L10N.register(
     "Voice" : "เสียงพูด",
     "Social network" : "เครือข่ายโซเชียล",
     "Relative" : "สัมพัทธ์",
-    "None" : "ไม่มี",
     "Unknown" : "ไม่ทราบ"
 },
 "nplurals=1; plural=0;");
