@@ -29,7 +29,6 @@ OC.L10N.register(
     "Update avatars from social media" : "从社交媒体更新头像",
     "(refreshed once per week)" : "(每周刷新)",
     "Address books" : "通讯录",
-    "Download" : "下载",
     "Send email" : "发送邮件",
     "Circles" : "圈子",
     "Create a new circle" : "新建一个圈子",
@@ -40,6 +39,7 @@ OC.L10N.register(
     "This group already exists" : "该群组已存在",
     "This circle already exists" : "这个圈子已经存在",
     "An error happened during the creation of the circle" : "创建圈子时发生一个错误",
+    "Download" : "下载",
     "Rename" : "重命名",
     "Enabled" : "已启用",
     "Delete" : "删除",
@@ -90,15 +90,13 @@ OC.L10N.register(
     "Enter a description for the circle" : "为这个圈子输入一个描述",
     "An error happened during description sync" : "描述同步期间发生一个错误",
     "An error happened during name sync" : "名称同步期间发生了一个错误",
-    "Add new property" : "新增属性",
-    "Choose property type" : "选择属性类型",
+    "Cancel" : "取消",
     "Upload a new picture" : "上传一张新的图片",
     "Choose from Files" : "从文件中选择",
     "Get from " : "获取自",
     "Download picture" : "下载图片",
     "Delete picture" : "删除图片",
     "Invalid image" : "无效的图像",
-    "Image is too big (max 1MB)." : "图片过大(最大1MB)",
     "Pick an avatar" : "选择一个头像",
     "Error while processing the picture." : "处理图片时出错。",
     "Avatar downloaded from social network" : "已从社交媒体下载头像",
@@ -107,16 +105,14 @@ OC.L10N.register(
     "No contact selected" : "请选择联系人",
     "Select a contact on the list to begin" : "请先在列表里选择联系人",
     "Name" : "名称",
-    "Company" : "公司",
     "Title" : "头衔",
+    "Company" : "公司",
     "This contact was broken and received a fix. Please review the content and click here to save it." : "此联系人已损坏但接收到了一个修复。请查看内容并点击这里以保存它。",
     "Clone contact" : "克隆联系人",
     "Generate QR Code" : "生成二维码",
     "Contact vCard as QR code" : "联系人名片作为二维码",
     "Pick an address book" : "选择一个地址簿",
     "Select address book" : "选择地址簿",
-    "Cancel" : "取消",
-    "This contact is not yet synced. Edit it to save it to the server." : "此联系人尚未同步。 编辑它以将其保存到服务器。",
     "This contact is in read-only mode. You do not have permission to edit this contact." : "此联系人处于只读模式。 您无权编辑此联系人。",
     "The contact you were trying to edit has changed. Please manually refresh the contact. Any further edits will be discarded." : "您尝试编辑的联系人已更改。 请手动刷新联系人。 任何进一步的编辑都不会被保存。",
     "Address book" : "地址簿",
@@ -124,7 +120,6 @@ OC.L10N.register(
     "Exclude contact from Birthday Calendar" : "从生日日历中排除联系人",
     "New contact" : "新建联系人",
     "Syntax error. Cannot open the contact." : "语法错误。不能打开联系人。",
-    "The contact does not exists on the server anymore." : "服务器上不再存在该联系人。",
     "Unable to retrieve the contact from the server, please check your network connection." : "无法从服务器取回联系人，请检查你的网络连接。",
     "An error occurred while trying to move the contact" : "尝试移动联系人时出错",
     "An error occurred while trying to copy the contact" : "尝试复制联系人时出错",
@@ -166,6 +161,7 @@ OC.L10N.register(
     "Select chart …" : "选择图表 …",
     "Select type" : "选择类型",
     "Select Date" : "选择日期",
+    "None" : "无",
     "Add contact in group" : "添加联系人到群组",
     "Select option" : "选择选项",
     "Unable to create the contact." : "未能成功创建联系人。",
@@ -212,11 +208,11 @@ OC.L10N.register(
     "Circle membership" : "圈子成员资格",
     "Prevent circle from being a member of another circle" : "防止圈子成为另一个圈子的成员",
     "Users" : "用户",
-    "Nickname" : "昵称",
     "Detailed name" : "全名",
     "Additional names" : "其他名称",
     "Prefix" : "前缀",
     "Suffix" : "后缀",
+    "Nickname" : "昵称",
     "Notes" : "说明",
     "Website" : "网站",
     "Location" : "地点",
@@ -267,12 +263,10 @@ OC.L10N.register(
     "Gender" : "性别",
     "Female" : "女性",
     "Male" : "男性",
-    "None" : "无",
     "Unknown" : "未知",
     "Time zone" : "时区",
     "Spoken languages" : "口语",
     "_{failed} contact failed to be read_::_{failed} contacts failed to be read_" : ["{failed} 个联系人读取失败"],
-    "Some circle(s) an error occurred. Check the console for more details." : "一些圈子出错了。更多详情见控制台",
     "Unable to create circle {circleName}" : "无法创建圈子 {circleName}",
     "Unable to delete circle {circleId}" : "无法删除圈子 {circleId}",
     "Unable to delete contact" : "无法删除联系人"
