@@ -29,8 +29,9 @@ OC.L10N.register(
     "Update avatars from social media" : "從社群媒體更新虛擬化身大頭照",
     "(refreshed once per week)" : "（每週重新整理一次）",
     "Address books" : "通訊錄",
-    "Download" : "下載",
+    "Export" : "導出",
     "Send email" : "傳送電郵",
+    "Send email as BCC" : "以 BCC 方式發送電郵",
     "Contact groups" : "聯絡群組",
     "Create a new contact group" : "創建新聯絡人群組",
     "Contact group name" : "聯絡人群組名稱",
@@ -43,6 +44,7 @@ OC.L10N.register(
     "This group already exists" : "該群組已存在",
     "This circle already exists" : "此社交圈子已存在",
     "An error happened during the creation of the circle" : "創建社交圈子的過程中發生錯誤",
+    "Download" : "下載",
     "Rename" : "重新命名",
     "Enabled" : "已啟用",
     "Delete" : "刪除",
@@ -93,15 +95,18 @@ OC.L10N.register(
     "Enter a description for the circle" : "輸入社交圈子的描述",
     "An error happened during description sync" : "描述同步期間發生錯誤",
     "An error happened during name sync" : "名稱同步期間發生錯誤",
-    "Add new property" : "新增屬性",
-    "Choose property type" : "選擇屬性類型",
+    "Add more info" : "添加更多資料",
+    "More fields" : "更多欄位",
+    "Crop contact photo" : "裁剪聯絡人照片",
+    "Cancel" : "取消",
     "Upload a new picture" : "上傳一張新的圖片",
     "Choose from Files" : "從檔案選取",
     "Get from " : "取自",
     "Download picture" : "下載圖片",
     "Delete picture" : "刪除圖片",
+    "Please select a valid format" : "請選擇有效的格式",
     "Invalid image" : "圖像無效",
-    "Image is too big (max 1MB)." : "圖像過大（最大 1MB）。",
+    "Error cropping picture" : "裁剪圖片時出錯",
     "Pick an avatar" : "選擇一個虛擬化身大頭照",
     "Error while processing the picture." : "處理相片時錯誤。",
     "Avatar downloaded from social network" : "從社群網路下載虛擬化身大頭照",
@@ -110,24 +115,24 @@ OC.L10N.register(
     "No contact selected" : "未選擇聯絡人",
     "Select a contact on the list to begin" : "在列表中選擇一個聯絡人以開始",
     "Name" : "姓名",
-    "Company" : "公司名稱",
     "Title" : "職銜",
+    "Company" : "公司名稱",
     "This contact was broken and received a fix. Please review the content and click here to save it." : "此聯絡人的資料有問題，已修復。請審閱內容並點擊此處以儲存。",
+    "Edit" : "編輯",
     "Clone contact" : "複製聯絡人",
     "Generate QR Code" : "生成 QR Code",
     "Contact vCard as QR code" : "QR Code 形式的聯絡人 vCard",
     "Pick an address book" : "選取一個通訊錄",
     "Select address book" : "選擇通訊錄",
-    "Cancel" : "取消",
-    "This contact is not yet synced. Edit it to save it to the server." : "此聯絡人尚未同步。編輯它以將其儲存到伺服器。",
     "This contact is in read-only mode. You do not have permission to edit this contact." : "此聯絡人處於唯讀模式。您無權編輯此聯絡人。",
     "The contact you were trying to edit has changed. Please manually refresh the contact. Any further edits will be discarded." : "您嘗試編輯的聯絡人已變更。請手動重新整理聯絡人。任何進一步的編輯都會被丟棄。",
     "Address book" : "通訊錄",
     "Add contact to Birthday Calendar" : "將聯絡人添加至生日日曆",
     "Exclude contact from Birthday Calendar" : "從生日日曆中排除聯絡人",
+    "{title} at {organization}" : "{organization} {title}",
     "New contact" : "新聯絡人",
     "Syntax error. Cannot open the contact." : "語法錯誤。無法開啟聯絡人。",
-    "The contact does not exists on the server anymore." : "伺服器上不再存在該聯絡人。",
+    "The contact does not exist on the server anymore." : "伺服器上不再存在該聯絡人。",
     "Unable to retrieve the contact from the server, please check your network connection." : "無法從伺服器擷取聯絡人，請檢查您的網路連線。",
     "An error occurred while trying to move the contact" : "嘗試移動聯絡人時發生錯誤",
     "An error occurred while trying to copy the contact" : "嘗試複製聯絡人時發生錯誤",
@@ -170,8 +175,10 @@ OC.L10N.register(
     "Select chart …" : "選擇圖表 ...",
     "Select type" : "選擇類型",
     "Select Date" : "選擇日期",
+    "None" : "無",
     "Add contact in group" : "新增聯絡人到群組",
     "Select option" : "選擇選項",
+    "Add property of this type" : "添加此類型的屬性",
     "Unable to create the contact." : "無法建立聯絡人",
     "Contact not found" : "找不到聯絡人",
     "Group {group} not found" : "找不到群組 {group}",
@@ -217,11 +224,11 @@ OC.L10N.register(
     "Prevent circle from being a member of another circle" : "防止社交圈子成為另一個圈子的成員",
     "Users" : "用戶",
     "Email addresses" : "電郵地址",
-    "Nickname" : "暱稱",
     "Detailed name" : "詳細名稱",
     "Additional names" : "別名/中間名",
     "Prefix" : "前綴",
     "Suffix" : "後綴",
+    "Nickname" : "暱稱",
     "Notes" : "備忘",
     "Website" : "網站",
     "Location" : "地點",
@@ -272,12 +279,11 @@ OC.L10N.register(
     "Gender" : "性別",
     "Female" : "女性",
     "Male" : "男性",
-    "None" : "無",
     "Unknown" : "不詳",
     "Time zone" : "時區",
     "Spoken languages" : "會說的語言",
     "_{failed} contact failed to be read_::_{failed} contacts failed to be read_" : ["{failed} 個聯絡人讀取失敗"],
-    "Some circle(s) an error occurred. Check the console for more details." : "某些圈子出錯，請查看控制台以獲取更多詳細信息。",
+    "An error has occurred in circle(s). Check the console for more details." : "圈子中出現錯誤。 請查看控制台以獲取更多詳細資訊。",
     "Unable to create circle {circleName}" : "無法創建社交圈子 {circleName}",
     "Unable to delete circle {circleId}" : "無法刪除社交圈子 {circleId}",
     "Unable to delete contact" : "無法刪除聯絡人"
