@@ -29,8 +29,9 @@ OC.L10N.register(
     "Update avatars from social media" : "從社群媒體更新大頭照",
     "(refreshed once per week)" : "（每週重新整理一次）",
     "Address books" : "通訊錄",
-    "Download" : "下載",
+    "Export" : "匯出",
     "Send email" : "傳送電子郵件",
+    "Send email as BCC" : "以密件副本傳送電子郵件",
     "Contact groups" : "聯絡人群組",
     "Create a new contact group" : "建立新聯絡人群組",
     "Contact group name" : "聯絡人群組名稱",
@@ -43,6 +44,7 @@ OC.L10N.register(
     "This group already exists" : "該群組已存在",
     "This circle already exists" : "此小圈圈已存在",
     "An error happened during the creation of the circle" : "建立小圈圈時發生錯誤",
+    "Download" : "下載",
     "Rename" : "重新命名",
     "Enabled" : "已啟用",
     "Delete" : "刪除",
@@ -93,15 +95,18 @@ OC.L10N.register(
     "Enter a description for the circle" : "輸入小圈圈的描述",
     "An error happened during description sync" : "描述同步時發生錯誤",
     "An error happened during name sync" : "名稱同步時發生錯誤",
-    "Add new property" : "新增屬性",
-    "Choose property type" : "選擇屬性類型",
+    "Add more info" : "新增更多資訊",
+    "More fields" : "更多欄位",
+    "Crop contact photo" : "裁剪聯絡人照片",
+    "Cancel" : "取消",
     "Upload a new picture" : "上傳一張新的圖片",
     "Choose from Files" : "從檔案選取",
     "Get from " : "取得自",
     "Download picture" : "下載圖片",
     "Delete picture" : "刪除圖片",
+    "Please select a valid format" : "請選取有效格式",
     "Invalid image" : "圖片無效",
-    "Image is too big (max 1MB)." : "圖檔過大（最大 1MB）。",
+    "Error cropping picture" : "裁剪照片時發生錯誤",
     "Pick an avatar" : "選擇一個大頭照",
     "Error while processing the picture." : "處理相片時錯誤。",
     "Avatar downloaded from social network" : "從社群網路下載大頭照",
@@ -110,24 +115,24 @@ OC.L10N.register(
     "No contact selected" : "未選擇聯絡人",
     "Select a contact on the list to begin" : "在列表中選擇一個聯絡人以開始",
     "Name" : "名稱",
-    "Company" : "公司",
     "Title" : "標題",
+    "Company" : "公司",
     "This contact was broken and received a fix. Please review the content and click here to save it." : "此聯絡人的資料有問題，已修復。請審閱內容並點擊此處以儲存。",
+    "Edit" : "退出",
     "Clone contact" : "再製連絡人",
     "Generate QR Code" : "產生 QR Code",
     "Contact vCard as QR code" : "QR Code 形式的聯絡人 vCard",
     "Pick an address book" : "選取一個通訊錄",
     "Select address book" : "選擇通訊錄",
-    "Cancel" : "取消",
-    "This contact is not yet synced. Edit it to save it to the server." : "此聯絡人尚未同步。編輯它以將其儲存到伺服器。",
     "This contact is in read-only mode. You do not have permission to edit this contact." : "此聯絡人處於唯讀模式。您無權編輯此聯絡人。",
     "The contact you were trying to edit has changed. Please manually refresh the contact. Any further edits will be discarded." : "您嘗試編輯的聯絡人已變更。請手動重新整理聯絡人。任何進一步的編輯都會被丟棄。",
     "Address book" : "通訊錄",
     "Add contact to Birthday Calendar" : "將聯絡人新增至生日行事曆",
     "Exclude contact from Birthday Calendar" : "從生日行事曆排除聯絡人",
+    "{title} at {organization}" : "{organization} 的 {title}",
     "New contact" : "新聯絡人",
     "Syntax error. Cannot open the contact." : "語法錯誤。無法開啟聯絡人。",
-    "The contact does not exists on the server anymore." : "伺服器上不再存在該聯絡人。",
+    "The contact does not exist on the server anymore." : "伺服器上不再存在該聯絡人。",
     "Unable to retrieve the contact from the server, please check your network connection." : "無法從伺服器擷取聯絡人，請檢查您的網路連線。",
     "An error occurred while trying to move the contact" : "嘗試移動聯絡人時發生錯誤",
     "An error occurred while trying to copy the contact" : "嘗試複製聯絡人時發生錯誤",
@@ -170,8 +175,10 @@ OC.L10N.register(
     "Select chart …" : "選取圖表……",
     "Select type" : "選取類型",
     "Select Date" : "選取日期",
+    "None" : "無",
     "Add contact in group" : "新增聯絡人到群組",
     "Select option" : "選取選項",
+    "Add property of this type" : "新增此類型的屬性",
     "Unable to create the contact." : "無法建立聯絡人",
     "Contact not found" : "找不到聯絡人",
     "Group {group} not found" : "找不到群組 {group}",
@@ -217,11 +224,11 @@ OC.L10N.register(
     "Prevent circle from being a member of another circle" : "避免小圈圈成為其他小圈圈的成員",
     "Users" : "使用者",
     "Email addresses" : "電子郵件地址",
-    "Nickname" : "暱稱",
     "Detailed name" : "詳細名稱",
     "Additional names" : "別名/中間名",
     "Prefix" : "前綴",
     "Suffix" : "後綴",
+    "Nickname" : "暱稱",
     "Notes" : "筆記",
     "Website" : "網站",
     "Location" : "地點",
@@ -272,12 +279,11 @@ OC.L10N.register(
     "Gender" : "性別",
     "Female" : "女性",
     "Male" : "男性",
-    "None" : "無",
     "Unknown" : "不明",
     "Time zone" : "時區",
     "Spoken languages" : "會說的語言",
     "_{failed} contact failed to be read_::_{failed} contacts failed to be read_" : ["{failed} 個聯絡人讀取失敗"],
-    "Some circle(s) an error occurred. Check the console for more details." : "部份小圈圈發生錯誤。請檢查主控台以取得更多資訊。",
+    "An error has occurred in circle(s). Check the console for more details." : "小圈圈中出現錯誤。請檢查主控台以取得更多詳細資訊。",
     "Unable to create circle {circleName}" : "無法建立小圈圈 {circleName}",
     "Unable to delete circle {circleId}" : "無法刪除小圈圈 {circleId}",
     "Unable to delete contact" : "無法刪除聯絡人"
