@@ -27,7 +27,6 @@ namespace OCA\Contacts\Service\Social;
  * Composition of all social providers for easier usage
  */
 class CompositeSocialProvider {
-
 	/** @var ISocialProvider[] */
 	private $providers;
 
@@ -38,8 +37,8 @@ class CompositeSocialProvider {
 								TumblrProvider $tumblrProvider,
 								DiasporaProvider $diasporaProvider,
 								XingProvider $xingProvider,
+								TelegramProvider $telegramProvider,
 								GravatarProvider $gravatarProvider) {
-
 		// This determines the priority of known providers
 		$this->providers = [
 			$instagramProvider->name => $instagramProvider,
@@ -49,6 +48,7 @@ class CompositeSocialProvider {
 			$tumblrProvider->name => $tumblrProvider,
 			$diasporaProvider->name => $diasporaProvider,
 			$xingProvider->name => $xingProvider,
+			$telegramProvider->name => $telegramProvider,
 			$gravatarProvider->name => $gravatarProvider
 		];
 	}
